const namespaced = true

const state = {
  proteinList: [],
}

const mutations = {
  ADD_PROTEIN (state, protein) {
    if(state.proteinList.findIndex(d => d.uniprot_id === protein.uniprot_id) < 0) {
      state.proteinList.push({uniprot_id: protein.uniprot_id,
        functional_type: protein.functional_type,
        proteins: protein.proteins,
        pubmed_ids: protein.pubmed_ids,
        driver_criterion: protein.driver_criterion,
        experimental_evidences: protein.experimental_evidences,
      })
    }
  },
  REMOVE_PROTEIN (state, proteinIdx) {
    state.proteinList.splice(proteinIdx, 1);
  },
  RESET_PROTEINS (state) {
    state.proteinList.splice(0, state.proteinList.length)
  },
}

const getters = {
  proteinList: state => state.proteinList,
}

const actions = {
  setProteinList ({ commit }, proteinList) {
    commit('SET_PROTEIN_LIST', proteinList)
  },
  addProtein ({ commit }, protein) {
    commit('ADD_PROTEIN', protein)
  },
  removeProtein ({ commit }, protein) {
    commit('REMOVE_PROTEIN', protein)
  },
  resetProteins ({ commit }) {
    commit('RESET_PROTEINS')
  },
}

export default {
  namespaced,
  state,
  mutations,
  getters,
  actions
}
